@@ -18,26 +18,10 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 use strict;
 use warnings;
+use lib qw( lib ../core/lib );
+use POE;
 use Haver::Server;
-use Getopt::Long;
-my $logfile  = '-';
-my $confdir  = './store';
-my $daemon   = 0;
-my $port;
 
-GetOptions (
-	"logfile=s"   => \$logfile,
-	"confdir=s"   => \$confdir,
-	'daemon'      => \$daemon,
-	'port=i'      => \$port,
-);
-
-my $chan = new Haver::Server::Channel(id => 'lobby');
-Haver::Server::Registry->instance->add($chan);
-
-Haver::Server->boot(
-	logfile => $logfile,
-	confdir => $confdir,
-	$port ? (port => $port) : (),
-	daemon  => $daemon,
-);
+$|++;
+create Haver::Server;
+POE::Kernel->run;
